﻿///////////////////////////////////////
//
//  Copyright 2014-2016 Brett Faulds
//
///////////////////////////////////////

using System.Collections.Generic;
using Boomlagoon.JSON;
using UnityEngine;
using System.Collections;

/// <summary>
/// The purpose of this class is to define all shapes in the game
///		it can be very dynamic on how long a shape can be
/// </summary>
public class Shape
{
	public int[,] ShapeLines;
	public int Size = MAX_SIZE;
	public string Name;

	public const int MAX_SIZE = 5;

	/// <summary>
	/// This is the constructor on how a shape is defined
	///		It is passed a JSONArray of what it kind of
	///		shape it will form.
	///		
	///		I.E [[0,1,0], [1,1,1]]
	/// </summary>
	/// <param name="shapeDefinition">The JSONArray (JSON File) that contains it definition</param>
	public Shape(JSONArray shapeDefinition, string shapeName)
	{
		Name = shapeName;

		List<int[]> lines = new List<int[]>();
		Size = shapeDefinition[0].Array.Length;
		for (int line = 0; line < Size; ++line)
		{
			if (line < shapeDefinition.Length)
			{
				JSONArray innerDef = shapeDefinition[line].Array;
				int[] shapeParams = new int[Size];
				for (int i = 0; i < Size; ++i)
				{
					if (i < innerDef.Length)
						shapeParams[i] = (int) innerDef[i].Number;
					else
						shapeParams[i] = 0;
				}

				lines.Add(shapeParams);
			}
			else
			{
				int[] shapeParams = new int[Size];
				for (int i = 0; i < Size; ++i)
				{
					shapeParams[i] = 0;
				}
				lines.Add(shapeParams);
			}
		}

		ShapeLines = new int[Size, Size];

		for (int i = 0; i < Size; ++i)
		{
			for (int x = 0; x < Size; ++x)
			{
				ShapeLines[i, x] = lines[i][x];
			}
		}
	}
}

///////////////////////////////////////
//
//  Copyright 2014-2016 Brett Faulds
//
///////////////////////////////////////