﻿///////////////////////////////////////
//
//  Copyright 2014-2016 Brett Faulds
//
///////////////////////////////////////

using UnityEngine;
using System.Collections;

/// <summary>
/// Purpose of this class is to define a shape in the game view
/// </summary>
public class ShapeObject
{
	private TetrisLine previousLine;
	public int ShapeID = -1;
	public int PositionX;
	public int PositionY;
	public int Size;
	public Color ShapeColor;

	public ShapeObject(TetrisLine line, int posX, int posY, int size, int shapeID, Color givenColor)
	{
		previousLine = line;
		PositionX = posX;
		PositionY = posY;
		Size = size;
		ShapeID = shapeID;
		ShapeColor = givenColor;
		line.UpdateLineBlock(posX, false, ShapeID, givenColor);
	}

	/// <summary>
	/// The next height to look at
	/// </summary>
	public int NextHeight
	{
		get { return PositionY - 1; }
	}

	/// <summary>
	/// Can the shape move to the left?
	/// </summary>
	/// <returns>If it can</returns>
	public bool MoveLeft()
	{
		if (PositionX > 0 && previousLine.IsBlockEmpty(PositionX - 1, ShapeID))
			return true;

		return false;
	}

	/// <summary>
	/// Move the shape to the left forcefully
	/// </summary>
	public void FinalizeMoveLeft()
	{
		previousLine.UpdateLineBlock(PositionX, true, ShapeID, ShapeColor);
		PositionX -= 1;
		previousLine.UpdateLineBlock(PositionX, false, ShapeID, ShapeColor);
	}

	/// <summary>
	/// Can the shape move to the right?
	/// </summary>
	/// <returns>If it can</returns>
	public bool MoveRight()
	{
		if (PositionX < 6 && previousLine.IsBlockEmpty(PositionX + 1, ShapeID))
			return true;

		return false;
	}

	/// <summary>
	/// Force the shape to move right
	/// </summary>
	public void FinalizeMoveRight()
	{
		previousLine.UpdateLineBlock(PositionX, true, ShapeID, ShapeColor);
		PositionX += 1;
		previousLine.UpdateLineBlock(PositionX, false, ShapeID, ShapeColor);
	}

	/// <summary>
	/// If this shape can move down or not
	/// </summary>
	/// <param name="lineBelow">Line to be checked</param>
	/// <returns>If it can</returns>
	public bool MoveDown(TetrisLine lineBelow)
	{
		if (lineBelow.IsBlockEmpty(PositionX, ShapeID))
			return true;
		return false;
	}

	/// <summary>
	/// Move the shape to the next line
	/// </summary>
	/// <param name="lineBelow"></param>
	public void FinalizeMove(TetrisLine lineBelow)
	{
		//Move it down
		lineBelow.UpdateLineBlock(PositionX, false, ShapeID, ShapeColor);
		previousLine.UpdateLineBlock(PositionX, true, ShapeID, ShapeColor);
		previousLine = lineBelow;
		PositionY--;
	}

	/// <summary>
	/// Remove the shape
	/// </summary>
	public void ClearShape()
	{
		previousLine.UpdateLineBlock(PositionX, true, -1, Color.white);
		PositionY = 0;
		ShapeID = -1;
	}
}

///////////////////////////////////////
//
//  Copyright 2014-2016 Brett Faulds
//
///////////////////////////////////////