﻿///////////////////////////////////////
//
//  Copyright 2014-2016 Brett Faulds
//
///////////////////////////////////////

using UnityEngine;
using System.Collections;

/// <summary>
/// The purpose of this class is to define the line that holds the TetrisBlocks
/// </summary>
public class TetrisLine : MonoBehaviour
{
	//Starting from left to right
	public TetrisBlock[] Blocks;

	/// <summary>
	/// If this line is full
	/// </summary>
	/// <returns>Whether the line is full</returns>
	public bool isLineFilled()
	{
		bool isFull = true;
		foreach (TetrisBlock block in Blocks)
		{
			if (block.IsEmpty)
			{
				isFull = false;
				break;
			}
		}

		return isFull;
	}

	/// <summary>
	/// The block is empty given an position and Shape ID
	/// </summary>
	/// <param name="id">Position</param>
	/// <param name="shapeIDCheck">Shape ID</param>
	/// <returns></returns>
	public bool IsBlockEmpty(int id, int shapeIDCheck)
	{
		if (Blocks.Length <= id)
		{
#if UNITY_EDITOR
			Debug.LogError("Shouldn't pass an id greater than tetris blocks [" + id + "]");
#endif
			return false;
		}

		if (shapeIDCheck == -1)
			return Blocks[id].IsEmpty;
		else
		{
			return Blocks[id].IsEmpty || Blocks[id].BlockID == shapeIDCheck;
		}
	}

	/// <summary>
	/// Updates a line block given the shape information
	/// </summary>
	/// <param name="id">Position</param>
	/// <param name="isEmpty">Whether it is empty or not</param>
	/// <param name="shapeID">ID of the shape</param>
	/// <param name="givenColor">Color of the block</param>
	public void UpdateLineBlock(int id, bool isEmpty, int shapeID, Color givenColor)
	{
		if (Blocks.Length <= id)
		{
#if UNITY_EDITOR
			Debug.LogError("Shouldn't pass an id greater than tetris blocks");
#endif
			return;
		}

		Blocks[id].UpdateBlock(isEmpty, shapeID, givenColor);
	}

	/// <summary>
	/// Clears this line
	/// </summary>
	public void ClearLine()
	{
		foreach (TetrisBlock block in Blocks)
		{
			block.UpdateBlock(true, -1, Color.white);
		}
	}

	/// <summary>
	/// Clones this line from another one
	/// </summary>
	/// <param name="line">Line to be cloned</param>
	public void CloneLine(TetrisLine line)
	{
		for (int x = 0; x < line.Blocks.Length; ++x)
		{
			Blocks[x].UpdateBlock(line.Blocks[x].IsEmpty, line.Blocks[x].BlockID, Color.white);
		}
	}
}

///////////////////////////////////////
//
//  Copyright 2014-2016 Brett Faulds
//
///////////////////////////////////////